hantekosc.py\_ht6022 package
============================

This package contains all important files of the Hantek6022API from github.
The library can be found at https://github.com/Ho-Ro/Hantek6022API.